==> groestlcoin_2.13.3~dfsg.orig.tar.gz: groestlcoin-2.13.3/src/qt/locale/bitcoin_sr@latin.ts <==
<TS language="sr@latin" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>Klikni desnim tasterom za uređivanje adrese ili oznake</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Kreiraj novu adresu</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Novi</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopiraj selektovanu adresu u sistemski klipbord</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopiraj</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>Zatvori</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Briše trenutno izabranu adresu sa liste</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Izvoz podataka iz trenutne kartice u datoteku</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Izvoz</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Izbrisati</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Dialog pristupne fraze</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Unesi pristupnu frazu</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nova pristupna fraza</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Ponovo unesite pristupnu frazu</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Unesite novu pristupnu frazu u novčanik. &lt;br/&gt;Molimo, koristite pristupnu frazu koja ima &lt;b&gt; deset ili više nasumičnih znakova&lt;/b&gt;, ili &lt;b&gt;osam ili više reči&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Šifrujte novčanik</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Da biste otključali novčanik potrebno je da unesete svoju pristupnu frazu.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Otključajte novčanik</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Da biste dešifrovali novčanik, potrebno je da unesete svoju pristupnu frazu.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Dešifrujte novčanik</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Promenite pristupnu frazu</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase to the wallet.</source>
        <translation>Unesite u novčanik staru pristupnu frazu i novu pristupnu frazu.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Potvrdite šifrovanje novčanika</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR GROESTLCOINS&lt;/b&gt;!</source>
        <translation>Upozorenje: Ako šifrujete svoj novčanik, i potom izgubite svoju pristupnu frazu &lt;b&gt;IZGUBIĆETE SVE SVOJE BITKOINE&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Da li ste sigurni da želite da šifrujete svoj novčanik?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Novčanik je šifrovan</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>IP/Netmask</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation>Banovani ste do</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Usklađivanje sa mrežom...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Pregled</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Isključi aplikaciju</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opcije...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Izmeni pristupnu frazu...</translation>
    </message>
    <message>
        <source>&amp;Sending addresses...</source>
        <translation>&amp;Slanje adresa...</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses...</source>
        <translation>&amp;Primanje adresa...</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Otvori &amp;URI...</translation>
    </message>
    <message>
        <source>Send coins to a Groestlcoin address</source>
        <translation>Pošalji novčiće na Groestlcoin adresu</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Proveri poruku...</translation>
    </message>
    <message>
        <source>Groestlcoin</source>
        <translation>Groestlcoin</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Novčanik</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Pošalji</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Primi</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Prikazati / Sakriti</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>Prikaži ili sakrij glavni prozor</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Podešavanja</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoć</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Greska</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Upozorenje</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informacije</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation>%1 klijent</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation>Datum: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation>Iznos: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation>Tip: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation>Oznaka: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation>Adresa: %1
</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Količina:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Iznos:</translation>
    </message>
    <message>
        <source>Priority:</source>
        <translation>Prioritet:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Naknada:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Nakon Naknade:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Kolicina</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Prioritet</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Izmeni Adresu</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Oznaka</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Adresa</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Error</source>
        <translation>Greska</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Kolicina</translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Količina:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Iznos:</translation>
    </message>
    <message>
        <source>Priority:</source>
        <translation>Prioritet:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Naknada:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Nakon Naknade:</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    </context>
<context>
    <name>TransactionView</name>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    </context>
<context>
    <name>groestlcoin-core</name>
    <message>
        <source>Groestlcoin Core</source>
        <translation>Groestlcoin Core</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informacije</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Upozorenje</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Nedovoljno sredstava</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Ucitavanje indeksa bloka...</translation>
    </message>
    <message>
        <source>Add a node to connect to and attempt to keep the connection open</source>
        <translation>Dodajte cvor za povezivanje, da bi pokusali da odrzite vezu otvorenom</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Ucitavanje novcanika...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>Nije moguce ispisivanje podrazumevane adrese</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Ponovno skeniranje...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Zavrseno ucitavanje</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Greska</translation>
    </message>
</context>
</TS>

==> groestlcoin_2.16.0~dfsg.orig.tar.gz: groestlcoin-2.16.0/src/qt/locale/bitcoin_sr@latin.ts <==
<TS language="sr@latin" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>Klikni desnim tasterom za uređivanje adrese ili oznake</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Kreiraj novu adresu</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Novi</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopiraj selektovanu adresu u sistemski klipbord</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopiraj</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>Zatvori</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Briše trenutno izabranu adresu sa liste</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Izvoz podataka iz trenutne kartice u datoteku</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Izvoz</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Izbrisati</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Izaberite adresu za slanje novčića</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Izaberite adresu za prijem novčića</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Adresa na koju se šalje</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Adresa na koju se prima</translation>
    </message>
    <message>
        <source>These are your Groestlcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Ovo su Vaše Groestlcoin adrese na koju se vrše uplate. Uvek proverite iznos i prijemnu adresu pre slanja novčića</translation>
    </message>
    <message>
        <source>These are your Groestlcoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
        <translation>Ovo su Vaše Groestlcoin adrese za primanje uplata. Preporučuje se upotreba nove adrese za svaku transakciju.</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kopiranje &amp;Oznaka</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Izmena</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Dialog pristupne fraze</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Unesi pristupnu frazu</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nova pristupna fraza</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Ponovo unesite pristupnu frazu</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Unesite novu pristupnu frazu u novčanik. &lt;br/&gt;Molimo, koristite pristupnu frazu koja ima &lt;b&gt; deset ili više nasumičnih znakova&lt;/b&gt;, ili &lt;b&gt;osam ili više reči&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Šifrujte novčanik</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Da biste otključali novčanik potrebno je da unesete svoju pristupnu frazu.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Otključajte novčanik</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Da biste dešifrovali novčanik, potrebno je da unesete svoju pristupnu frazu.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Dešifrujte novčanik</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Promenite pristupnu frazu</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase to the wallet.</source>
        <translation>Unesite u novčanik staru pristupnu frazu i novu pristupnu frazu.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Potvrdite šifrovanje novčanika</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR GROESTLCOINS&lt;/b&gt;!</source>
        <translation>Upozorenje: Ako šifrujete svoj novčanik, i potom izgubite svoju pristupnu frazu &lt;b&gt;IZGUBIĆETE SVE SVOJE BITKOINE&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Da li ste sigurni da želite da šifrujete svoj novčanik?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Novčanik je šifrovan</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>IP/Netmask</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation>Banovani ste do</translation>
    </message>
</context>
<context>
    <name>GroestlcoinGUI</name>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Usklađivanje sa mrežom...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Pregled</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Isključi aplikaciju</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;Otprilike %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>Prikaži informacije za otprilike %1</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opcije...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Izmeni pristupnu frazu...</translation>
    </message>
    <message>
        <source>&amp;Sending addresses...</source>
        <translation>&amp;Slanje adresa...</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses...</source>
        <translation>&amp;Primanje adresa...</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Otvori &amp;URI...</translation>
    </message>
    <message>
        <source>Send coins to a Groestlcoin address</source>
        <translation>Pošalji novčiće na Groestlcoin adresu</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Proveri poruku...</translation>
    </message>
    <message>
        <source>Groestlcoin</source>
        <translation>Groestlcoin</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Novčanik</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Pošalji</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Primi</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Prikazati / Sakriti</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>Prikaži ili sakrij glavni prozor</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Podešavanja</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoć</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Greska</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Upozorenje</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informacije</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation>%1 klijent</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation>Datum: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation>Iznos: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation>Tip: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation>Oznaka: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation>Adresa: %1
</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Količina:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Iznos:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Naknada:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Nakon Naknade:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Kolicina</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Izmeni Adresu</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Oznaka</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Adresa</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Error</source>
        <translation>Greska</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Kolicina</translation>
    </message>
    </context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Količina:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Iznos:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Naknada:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Nakon Naknade:</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    </context>
<context>
    <name>TransactionView</name>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    </context>
<context>
    <name>groestlcoin-core</name>
    <message>
        <source>Groestlcoin Core</source>
        <translation>Groestlcoin Core</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informacije</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Upozorenje</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Nedovoljno sredstava</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Ucitavanje indeksa bloka...</translation>
    </message>
    <message>
        <source>Add a node to connect to and attempt to keep the connection open</source>
        <translation>Dodajte cvor za povezivanje, da bi pokusali da odrzite vezu otvorenom</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Ucitavanje novcanika...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>Nije moguce ispisivanje podrazumevane adrese</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Ponovno skeniranje...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Zavrseno ucitavanje</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Greska</translation>
    </message>
</context>
</TS>
